@@ -2,7 +2,18 @@ import logging
 from django.conf import settings
 
 
+__all__ = ['patch']
+
+
+# Idempotence! http://en.wikipedia.org/wiki/Idempotence
+_has_patched = False
+
+
 def patch():
+    global _has_patched
+    if _has_patched:
+        return
+
     # Import for side-effect: configures logging handlers.
     # pylint: disable-msg=W0611
     import log_settings
@@ -17,5 +28,10 @@ def patch():
     if 'session_csrf' in settings.INSTALLED_APPS:
         import session_csrf
         session_csrf.monkeypatch()
+        from . import admin
+        admin.monkeypatch()
 
     logging.debug("Note: funfactory monkey patches executed in %s" % __file__)
+
+    # prevent it from being run again later
+    _has_patched = True
