@@ -137,7 +137,7 @@ DOMAIN_METHODS = {
 }
 
 # Paths that don't require a locale code in the URL.
-SUPPORTED_NONLOCALES = ['media', 'admin']
+SUPPORTED_NONLOCALES = ['media', 'static', 'admin']
 
 
 ## Media and templates.
@@ -151,10 +151,15 @@ MEDIA_ROOT = path('media')
 # Examples: "http://media.lawrence.com", "http://example.com/media/"
 MEDIA_URL = '/media/'
 
-# URL prefix for admin media -- CSS, JavaScript and images. Make sure to use a
-# trailing slash.
-# Examples: "http://foo.com/media/", "/media/".
-ADMIN_MEDIA_PREFIX = '/admin-media/'
+# Absolute path to the directory static files should be collected to.
+# Don't put anything in this directory yourself; store your static files
+# in apps' "static/" subdirectories and in STATICFILES_DIRS.
+# Example: "/home/media/media.lawrence.com/static/"
+STATIC_ROOT = path('static')
+
+# URL prefix for static files.
+# Example: "http://media.lawrence.com/static/"
+STATIC_URL = '/static/'
 
 # Make this unique, and don't share it with anybody.
 # Set this in your local settings which is not committed to version control.
@@ -223,13 +228,14 @@ INSTALLED_APPS = (
     'jingo_minify',
     'tower',  # for ./manage.py extract (L10n)
     'cronjobs',  # for ./manage.py cron * cmd line tasks
+    'django_browserid',
 
 
     # Django contrib apps
     'django.contrib.auth',
-    'django_sha2',  # Load after auth to monkey-patch it.
     'django.contrib.contenttypes',
     'django.contrib.sessions',
+    'django.contrib.staticfiles',
     # 'django.contrib.sites',
     # 'django.contrib.messages',
     # Uncomment the next line to enable the admin:
@@ -256,11 +262,25 @@ JAVA_BIN = '/usr/bin/java'
 SESSION_COOKIE_HTTPONLY = True
 
 ## Auth
-PWD_ALGORITHM = 'sha512'  # recommended: 'bcrypt'
+# The first hasher in this list will be used for new passwords.
+# Any other hasher in the list can be used for existing passwords.
+# Playdoh ships with Bcrypt+HMAC by default because it's the most secure.
+# To use bcrypt, fill in a secret HMAC key in your local settings.
+BASE_PASSWORD_HASHERS = (
+    'django_sha2.hashers.BcryptHMACCombinedPasswordVerifier',
+    'django_sha2.hashers.SHA512PasswordHasher',
+    'django_sha2.hashers.SHA256PasswordHasher',
+    'django.contrib.auth.hashers.SHA1PasswordHasher',
+    'django.contrib.auth.hashers.MD5PasswordHasher',
+    'django.contrib.auth.hashers.UnsaltedMD5PasswordHasher',
+)
 HMAC_KEYS = {  # for bcrypt only
-    #'2011-01-01': 'cheesecake',
+    #'2012-06-06': 'cheesecake',
 }
 
+from django_sha2 import get_password_hashers
+PASSWORD_HASHERS = get_password_hashers(BASE_PASSWORD_HASHERS, HMAC_KEYS)
+
 ## Tests
 TEST_RUNNER = 'test_utils.runner.RadicalTestSuiteRunner'
 
